@@ -14,18 +14,17 @@ import logging
 
 from aiokafka import ConsumerRecord
 
-from async_tools import AsyncOnStart
 from kafka_tools.kafka_client.consumer import Consumer
 from kafka_tools.kafka_client.producer import Producer
 from init_helpers.dict_to_dataclass import dict_to_dataclass, T
 
 
 logger = logging.getLogger(__name__)
-DetectionAnalyzeResult = Type[T]
-AnalyzeResultCallback = Callable[[DetectionAnalyzeResult], Awaitable[Any]]
+DetectionAnalyzeResultType = Type[T]
+AnalyzeResultCallback = Callable[[DetectionAnalyzeResultType], Awaitable[Any]]
 
 
-class DetectorKafkaConnector(AsyncOnStart):
+class DetectorKafkaConnector:
     @dataclass
     class Config:
         detector_task_topic: str
@@ -36,7 +35,10 @@ class DetectorKafkaConnector(AsyncOnStart):
         kafka_producer: Producer
         kafka_consumer: Consumer
 
-    def __init__(self, config: Config, context: Context, detector_analyze_result_type: Type[T]) -> None:
+    def __init__(self,
+                 config: Config,
+                 context: Context,
+                 detector_analyze_result_type: DetectionAnalyzeResultType) -> None:
         self.config = config
         self.context = context
         self.detector_analyze_result_type = detector_analyze_result_type
